@@ -1,11 +1,12 @@
 package Dist::Zilla::Role::DumpPerinciCmdLineScript;
 
-our $DATE = '2015-12-08'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-01-10'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose::Role;
 
+use Data::Dmp;
 use Perinci::CmdLine::Dump;
 
 sub dump_perinci_cmdline_script {
@@ -29,10 +30,13 @@ sub dump_perinci_cmdline_script {
 
     $self->log_debug(["Dumping Perinci::CmdLine script '%s'", $filename]);
 
-    Perinci::CmdLine::Dump::dump_perinci_cmdline_script(
+    my $res = Perinci::CmdLine::Dump::dump_perinci_cmdline_script(
         filename => $filename,
         libs => ['lib'],
     );
+
+    $self->log_debug(["Dump result: %s", dmp($res)]);
+    $res;
 }
 
 no Moose::Role;
@@ -51,7 +55,7 @@ Dist::Zilla::Role::DumpPerinciCmdLineScript - Role to dump Perinci::CmdLine scri
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Role::DumpPerinciCmdLineScript (from Perl distribution Dist-Zilla-Role-DumpPerinciCmdLineScript), released on 2015-12-08.
+This document describes version 0.03 of Dist::Zilla::Role::DumpPerinciCmdLineScript (from Perl distribution Dist-Zilla-Role-DumpPerinciCmdLineScript), released on 2016-01-10.
 
 =head1 METHODS
 
@@ -84,7 +88,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
